## cdf 

### Added

- [Alpha] Added the `cdf migrate prepare` command that is used to deploy
the `CogniteMigrate` model used to store mappings from asset-centric to
data modeling.

## templates

No changes.